@@ -1,7 +1,7 @@
 import boto3
 import ast
 from aws.ec2 import get_instance, set_current_vpcid, get_vpc
-from aws.region import get_elb, get_elbv2
+from aws.region import get_elb, get_elbv2, get_acm
 
 ###########################################################################
 # Elastic Load Balancers
@@ -660,3 +660,12 @@ def get_elb_tags(arn: str) -> list:
         val = x.get('Value')
         res[key] = val
     return res
+
+###########################################################################
+# Certificate Manager
+###########################################################################
+def get_certs():
+    """
+    :return: list of certificates issued in the region, each with the keys 'CertificateARN' and 'DomainName'
+    """
+    return get_acm().list_certificates(CertificateStatuses = ['ISSUED'])
\ No newline at end of file
