@@ -462,7 +462,7 @@ def get_db_sg(id: str):
 ###########################################################################
 # Tags
 ###########################################################################
-def get_tags(arn: str):
+def get_rds_tags(arn: str):
     """
     List the tags associated with the RDS object
 
