@@ -1,5 +1,5 @@
 from unittest import TestCase, mock
-from aws.secret import get_secret_value, create_secret, delete_secret
+from aws.secret import get_secret_value, create_secret, delete_secret, update_secret
 import time, json
 
 class TestSecret(TestCase):
@@ -73,4 +73,29 @@ class TestSecret(TestCase):
       delete_secret('test-get-secret-plain', perma_delete = True)
       delete_secret('test-get-secret-json', perma_delete = True)
       delete_secret('test-get-secret-json-key', perma_delete = True)
-      delete_secret('test-get-secret-binary', perma_delete = True)
\ No newline at end of file
+      delete_secret('test-get-secret-binary', perma_delete = True)
+
+  def test_update_secret(self):
+    try:
+      create_secret('test-update-secret-plain', 'test updating secrets while unit testing secrets manager', string = 'asdf')
+      update_secret('test-update-secret-plain', string = 'jkljkl')
+      self.assertEqual(get_secret_value('test-update-secret-plain'), 'jkljkl')
+
+      create_secret('test-update-secret-json', 'test updating secrets while unit testing secrets manager', kvp = {'this': 'is', 'values': 'definition'})
+      update_secret('test-update-secret-json', kvp = {'additional': 'pairs', 'get': 'added'})
+      res = json.loads(get_secret_value('test-update-secret-json'))
+      self.assertEquals(res, {'this': 'is', 'values': 'definition', 'additional': 'pairs', 'get': 'added'})
+
+      create_secret('test-update-secret-json-overwrite', 'test updating json secret and overwriting', kvp = {'a': 'asdf', 'b': 'bnm,', 'c': 'cvbn'})
+      overwriter = {'d': 'zxcv', 'e': 'uiop'}
+      update_secret('test-update-secret-json-overwrite', kvp = overwriter, overwriteJson = True)
+      self.assertEqual(json.loads(get_secret_value('test-update-secret-json-overwrite')), overwriter)
+
+      create_secret('test-update-secret-binary', 'test getting binary value from secret', binary = b'asdfghjkl')
+      update_secret('test-update-secret-binary', binary = b'jklasdf')
+      self.assertEqual(get_secret_value('test-update-secret-binary'), b'jklasdf')
+    finally:
+      delete_secret('test-update-secret-plain', perma_delete = True)
+      delete_secret('test-update-secret-json', perma_delete = True)
+      delete_secret('test-update-secret-json-overwrite', perma_delete = True)
+      delete_secret('test-update-secret-binary', perma_delete = True)
\ No newline at end of file
